@@ -25,7 +25,8 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (drd-group latex-command-0%
-  #{\ }# #{\;}# #{\,}# #{\:}#
+  ,(string->symbol " ") ,(string->symbol ";") 
+  ,(string->symbol ",") ,(string->symbol ":") 
   - / [ ] ! * | i j ss SS oe OE ae AE
   AA DH L NG O S TH aa dh dj l ng o th pounds
   quad qquad par smallskip medskip bigskip
@@ -37,9 +38,10 @@
 
   ;; temporarily
   hline
-
   ;; rewritten
-  notin vert Vert addots)
+  notin vert Vert addots
+  ;; wikipedia
+  infin rang)
 
 (drd-group latex-command-1%
   usepackage part part* chapter chapter*
@@ -52,7 +54,8 @@
   dot ddot dddot ddddot
   label ref pageref index hspace hspace* vspace vspace*
   mbox hbox text not
-  #{\'}# #{\`}# #{\"}# ^ over ~ = u v H t c d b k r thispagestyle ensuremath
+  ,(string->symbol "'") ,(string->symbol "`") ,(string->symbol "\"")
+  ^ over ~ = u v H t c d b k r thispagestyle ensuremath
   mathord mathbin mathopen mathpunct mathop mathrel mathclose mathalpha
   arabic displaylines cases underbrace overbrace
   includegraphics url penalty
@@ -65,7 +68,8 @@
   ,(string->symbol "."))
 
 (drd-group latex-command-2%
-  binom choose sideset stackrel citeauthoryear setcounter equal
+  binom choose cfrac tfrac
+  sideset stackrel citeauthoryear setcounter equal
   href)
 
 (drd-group latex-command-3%
@@ -86,7 +90,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (drd-group latex-command-0*%
-  item #{\\}#)
+  item ,(string->symbol "\\"))
 
 (drd-group latex-command-1*%
   documentclass documentstyle sqrt bibitem cite)
@@ -113,7 +117,8 @@
 
 (drd-group latex-environment-0%
   begin-document begin-abstract begin-verbatim
-  begin-matrix begin-pmatrix begin-center begin-picture)
+  begin-matrix begin-pmatrix begin-bmatrix begin-vmatrix
+  begin-center begin-picture)
 
 (drd-group latex-environment-0*%
   begin-figure begin-table)
@@ -166,7 +171,7 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (drd-group latex-control%
-  $ & % #{\#}# _ { } <less> <gtr>)
+  $ & % ,(string->symbol "#") _ { } <less> <gtr>)
 
 (drd-group latex-operator%
   arccos arcsin arctan arg cos cosh cot coth csc deg det dim exp gcd hom
