@@ -117,7 +117,8 @@
   (in-plugin-with-converters%
    (plugin-supports-math-input-ref (get-env "prog-language")))
   (with-active-selection% (selection-active-normal?))
-  (in-scheme% (== (get-env "prog-language") "scheme")))
+  (in-scheme% (== (get-env "prog-language") "scheme"))
+  (in-prog-scheme% #t in-prog% in-scheme%))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Language related
