@@ -24,3 +24,21 @@
 	(else (kw-transform (cdr l)))))
 
 (eval (cons 'begin (kw-transform kwo)))
+
+(define indent-arity-table (make-ahash-table))
+
+(define (indent-set-arity x nr)
+  (cond ((symbol? x) (indent-set-arity (symbol->string x) nr))
+	((string? x) (ahash-set! indent-arity-table x nr))
+	((list? x) (for-each (cut indent-set-arity <> nr) x))))
+
+(indent-set-arity nullary-indent 0)
+(indent-set-arity unary-indent   1)
+(indent-set-arity binary-indent  2)
+(indent-set-arity ternary-indent 3)
+
+(tm-define (indent-get-arity s)
+  (:synopsis "get indentation arity of keyword @s")
+  (if (symbol? s)
+      (indent-get-arity (symbol->string s))
+      (ahash-ref indent-arity-table s)))
