@@ -69,6 +69,7 @@ filter_preamble (tree t) {
 #define t2e parsed_text_to_tree
 #define m2e latex_modifier_to_tree
 #define var_m2e var_latex_modifier_to_tree
+#define v2e latex_verbarg_to_string
 tree l2e (tree);
 tree latex_command_to_tree (tree t);
 
@@ -136,6 +137,8 @@ latex_symbol_to_tree (string s) {
       if (s == "\\notin") return "<nin>";
       if (s == "\\addots") return "<udots>";
       if (s == "\\dots") return "<ldots>";
+      if (s == "\\infin") return "<infty>";
+      if (s == "\\rang") return "<rangle>";
       if (s == "\\tableofcontents")
 	return compound ("table-of-contents", "toc", tree (DOCUMENT, ""));
     }
@@ -377,19 +380,9 @@ var_m2e (tree t, string var, string val) {
 	       tree (RESET, copy (var)));
 }
 
-tree
-latex_verbarg_to_tree (tree t) {
-  t= l2e (t);
-  if (is_concat (t)) {
-    string s;
-    int i, n= N(t);
-    for (i=0; i<n; i++)
-      if (is_atomic (t[i])) s << t[i]->label;
-      else if (is_func (t[i], RSUB, 1) && is_atomic (t[i][0]))
-	s << "_" << t[i][0]->label;
-    return s;
-  }
-  else return "";
+string
+v2e (tree t) {
+  return string_arg (t2e (t, false));
 }
 
 static bool
@@ -639,12 +632,12 @@ latex_command_to_tree (tree t) {
   }
   if (is_tuple (t, "\\cite", 1) || is_tuple (t, "\\nocite", 1)) {
     string cite_type= t[0]->label (1, N(t[0]->label));
-    string s= string_arg (t2e(t[1]));
+    string s= v2e (t[1]);
     return latex_cite_to_tree (cite_type, s);
   }
   if (is_tuple (t, "\\cite*", 2)) {
     tree   ot= t2e(t[1])->label;
-    string s = string_arg (t2e(t[2]));
+    string s = v2e (t[2]);
     tree   ct= latex_cite_to_tree ("cite", s);
     if (N(ct) == 2) return compound ("cite-detail", ct[1], ot);
     return tree (CONCAT, ct, " (", ot, ")");
@@ -665,7 +658,7 @@ latex_command_to_tree (tree t) {
       if (cite_type == "citep") cite_type= "cite-parenthesized" * star;
       if (cite_type == "citealt") cite_type= "cite-raw" * star;
       if (cite_type == "citealp") cite_type= "cite-raw" * star;
-      string s= string_arg (t2e(t[1]));
+      string s= v2e (t[1]);
       return latex_cite_to_tree (cite_type, s);
     }
   if (is_tuple (t, "\\citetext", 1))
@@ -676,8 +669,12 @@ latex_command_to_tree (tree t) {
     textm_natbib= true; return compound ("cite-author*-link", t2e (t[1])); }
   if (is_tuple (t, "\\citeyear", 1)) {
     textm_natbib= true; return compound ("cite-year-link", t2e (t[1])); }
+  if (is_tuple (t, "\\bibitem", 1))
+    return compound ("bibitem", v2e (t[1]));
+  if (is_tuple (t, "\\bibitem*", 2))
+    return compound ("bibitem*", v2e (t[1]), v2e (t[2]));
   if (is_tuple (t, "\\index", 1)) {
-    string s= string_arg (t2e (t[1]));
+    string s= v2e (t[1]);
     return latex_index_to_tree (s);
   }
   if (is_tuple (t, "\\displaylines", 1)) {
@@ -692,7 +689,7 @@ latex_command_to_tree (tree t) {
     return r;
   }
   if (is_tuple (t, "\\includegraphics", 1)) {
-    tree name= latex_verbarg_to_tree (t[1]);
+    tree name= v2e (t[1]);
     if (name == "") return "";
     else {
       tree g (POSTSCRIPT, 7);
@@ -839,9 +836,9 @@ parse_matrix_params (tree t) {
 }
 
 static void
-parse_pmatrix (tree& r, tree t, int& i, bool bracket) {
+parse_pmatrix (tree& r, tree t, int& i, string lb, string rb) {
   tree tformat= parse_matrix_params (t[i]);
-  if (bracket) r << tree (LEFT, "(");
+  if (lb != "") r << tree (LEFT, lb);
 
   int rows=0, cols=0;
   tree V (CONCAT);
@@ -863,17 +860,27 @@ parse_pmatrix (tree& r, tree t, int& i, bool bracket) {
       continue;
     }
     else if (is_func (v, BEGIN) && ((v[0] == "array") ||(v[0] == "tabular"))) {
-      parse_pmatrix (E, t, i, false);
+      parse_pmatrix (E, t, i, "", "");
       if (i<N(t)) continue;
       break;
     }
     else if (v == tree (BEGIN, "matrix")) {
-      parse_pmatrix (E, t, i, false);
+      parse_pmatrix (E, t, i, "", "");
       if (i<N(t)) continue;
       break;
     }
     else if (v == tree (BEGIN, "pmatrix")) {
-      parse_pmatrix (E, t, i, true);
+      parse_pmatrix (E, t, i, "(", ")");
+      if (i<N(t)) continue;
+      break;
+    }
+    else if (v == tree (BEGIN, "bmatrix")) {
+      parse_pmatrix (E, t, i, "{", "}");
+      if (i<N(t)) continue;
+      break;
+    }
+    else if (v == tree (BEGIN, "vmatrix")) {
+      parse_pmatrix (E, t, i, "|", "|");
       if (i<N(t)) continue;
       break;
     }
@@ -881,6 +888,8 @@ parse_pmatrix (tree& r, tree t, int& i, bool bracket) {
     else if (v == tree (END, "tabular")) break;
     else if (v == tree (END, "matrix")) break;
     else if (v == tree (END, "pmatrix")) break;
+    else if (v == tree (END, "bmatrix")) break;
+    else if (v == tree (END, "vmatrix")) break;
     else if (v == tree (APPLY, "hline")) {
       int    row  = N(V)+ (N(L)==0? 0: 1);
       string row_s= row==0? as_string (row+1): as_string (row);
@@ -913,7 +922,7 @@ parse_pmatrix (tree& r, tree t, int& i, bool bracket) {
     M= tformat;
   }
   r << M;
-  if (bracket) r << tree (RIGHT, ")");
+  if (rb != "") r << tree (RIGHT, rb);
 }
 
 static tree
@@ -926,10 +935,12 @@ finalize_pmatrix (tree t) {
     tree r (CONCAT);
     for (i=0; i<n; i++)
       if (is_func (u[i], BEGIN)) {
-	if (u[i][0] == "array") parse_pmatrix (r, u, i, false);
-	else if (u[i][0] == "tabular") parse_pmatrix (r, u, i, false);
-	else if (u[i][0] == "matrix") parse_pmatrix (r, u, i, false);
-	else if (u[i][0] == "pmatrix") parse_pmatrix (r, u, i, true);
+	if (u[i][0] == "array") parse_pmatrix (r, u, i, "", "");
+	else if (u[i][0] == "tabular") parse_pmatrix (r, u, i, "", "");
+	else if (u[i][0] == "matrix") parse_pmatrix (r, u, i, "", "");
+	else if (u[i][0] == "pmatrix") parse_pmatrix (r, u, i, "(", ")");
+	else if (u[i][0] == "bmatrix") parse_pmatrix (r, u, i, "[", "]");
+	else if (u[i][0] == "vmatrix") parse_pmatrix (r, u, i, "|", "|");
 	else r << u[i];
       }
       else r << u[i];
