@@ -410,7 +410,7 @@ upgrade_textual (tree t, path& mode_stack) {
 	else s << ss;
       }
       else if (((t->label[i] == '\'') || (t->label[i] == '`')) &&
-	       (!nil (mode_stack)) && (mode_stack->item == 1))
+	       (!is_nil (mode_stack)) && (mode_stack->item == 1))
 	{
 	  int start= i++;
 	  while ((i<n) && (t->label[i] == t->label[i-1])) i++;
@@ -436,7 +436,7 @@ upgrade_textual (tree t, path& mode_stack) {
       }
       else if (is_func (u, RESET)) {
 	if (u == tree (RESET, "mode"))
-	  if (!nil (mode_stack))
+	  if (!is_nil (mode_stack))
 	    mode_stack= mode_stack->next;
       }
       else if (is_func (u, BEGIN, 1)) {
@@ -451,7 +451,7 @@ upgrade_textual (tree t, path& mode_stack) {
 	    (u[0] == "equation*") ||
 	    (u[0] == "eqnarray*") ||
 	    (u[0] == "leqnarray*"))
-	  if (!nil (mode_stack))
+	  if (!is_nil (mode_stack))
 	    mode_stack= mode_stack->next;
       }
       if (is_concat (t) && is_concat (u)) r << A(u);
@@ -482,7 +482,7 @@ upgrade_apply_expand_value (tree t, hashset<string> H) {
   }
 }
 
-typedef char* charp;
+typedef const char* charp;
 static charp apply_expand_value_strings[]= {
   "part", "part*", "chapter", "chapter*", "appendix",
   "section", "section*", "subsection", "subsection*",
@@ -2738,6 +2738,37 @@ upgrade_scheme_doc (tree t) {
   }
 }
 
+/******************************************************************************
+* Upgrade Mathemagix tag
+******************************************************************************/
+
+tree
+upgrade_mmx (tree t) {
+  int i;
+  if (is_atomic (t)) return t;
+  else if (is_compound (t, "mmx", 0) || t == tree (VALUE, "mmx"))
+    return compound ("mathemagix");
+  else if (is_compound (t, "mml", 0) || t == tree (VALUE, "mml"))
+    return compound ("mmxlib");
+  else if (is_compound (t, "scheme", 0) || t == tree (VALUE, "scheme"))
+    return compound ("scheme");
+  else if (is_compound (t, "cpp", 0) || t == tree (VALUE, "cpp"))
+    return compound ("c++");
+  else if (is_compound (t, "scheme-code", 1))
+    return compound ("scm", upgrade_mmx (t[0]));
+  else if (is_compound (t, "scheme-fragment", 1))
+    return compound ("scm-fragment", upgrade_mmx (t[0]));
+  else if (is_compound (t, "cpp-code", 1))
+    return compound ("cpp", upgrade_mmx (t[0]));
+  else {
+    int n= N(t);
+    tree r (t, n);
+    for (i=0; i<n; i++)
+      r[i]= upgrade_mmx (t[i]);
+    return r;
+  }
+}
+
 /******************************************************************************
 * Upgrade from previous versions
 ******************************************************************************/
@@ -2850,5 +2881,7 @@ upgrade (tree t, string version) {
     t= upgrade_label_assignment (t);
   if (version_inf_eq (version, "1.0.6.10"))
     t= upgrade_scheme_doc (t);
+  if (version_inf_eq (version, "1.0.6.14"))
+    t= upgrade_mmx (t);
   return t;
 }
