@@ -578,7 +578,7 @@ fnsymbol_nr (int nr) {
 * Conversions to and from hexadecimal
 ******************************************************************************/
 
-static char* hex_string= "0123456789ABCDEF";
+static const char* hex_string= "0123456789ABCDEF";
 
 string
 as_hexadecimal (int i) {
@@ -776,6 +776,8 @@ escape_sh (string s) {
   string r;
   for (i=0; i<n; i++)
     switch (s[i]) {
+    case '?':
+    case '&':
     case '$':
     case '`':
     case '\"':
@@ -873,7 +875,7 @@ starts (string s, const string what) {
 
 bool
 ends (string s, const char* what) {
-  string r ((char*) what);
+  string r (what);
   if (N(r) > N(s)) return false;
   return s (N(s)-N(r), N(s)) == r;
 }
