@@ -38,7 +38,7 @@ edit_typeset_rep::edit_typeset_rep ():
   the_style (TUPLE),
   cur (hashmap<string,tree> (UNINIT)),
   pre (UNINIT), init (UNINIT), fin (UNINIT),
-  env (dis, drd, is_aux (buf->name)? buf->extra: buf->name,
+  env (drd, is_aux (buf->name)? buf->extra: buf->name,
        buf->ref, (buf->prj==NULL? buf->ref: buf->prj->ref),
        buf->aux, (buf->prj==NULL? buf->aux: buf->prj->aux)),
   ttt (new_typesetter (env, subtree (et, rp), reverse (rp))) {}
@@ -358,6 +358,10 @@ edit_typeset_rep::exec_html (tree t, path p) {
   hashmap<string,tree> P (UNINIT, patch);
   H->join (P);
   return exec (t, H);
+  //tree r= exec (t, H);
+  //cout << "In: " << t << "\n";
+  //cout << "Out: " << r << "\n";
+  //return r;
 }
 
 tree
