@@ -16,27 +16,28 @@
 #include "link.hpp"
 #include "analyze.hpp"
 #include "drd_mode.hpp"
+#include "message.hpp"
+#include "window.hpp"
 
 /******************************************************************************
 * dispatching
 ******************************************************************************/
 
 void
-edit_interface_rep::mouse_any (string type, SI x, SI y, time_t t) {
+edit_interface_rep::mouse_any (string type, SI x, SI y, int mods, time_t t) {
   last_x= x; last_y= y;
   mark_undo_blocks ();
-  if (type != "move" || (attached () && !dis->check_event (MOTION_EVENT)))
+  if (type != "move" || (is_attached (this) && !check_event (MOTION_EVENT)))
     update_active_loci ();
 
   if (type == "leave")
     set_pointer ("XC_top_left_arrow");
   if ((type != "move") && (type != "enter") && (type != "leave"))
     set_input_normal ();
-  if ((popup_win != NULL) && (type != "leave")) {
-    popup_win->map ();
-    delete popup_win;
-    popup_win= NULL;
-    this << emit_mouse_grab (false);
+  if (!is_nil (popup_win) && (type != "leave")) {
+    set_visibility (popup_win, false);
+    destroy_window_widget (popup_win);
+    popup_win= widget ();
   }
 
   if (inside_graphics (false)) {
@@ -74,19 +75,19 @@ edit_interface_rep::mouse_any (string type, SI x, SI y, time_t t) {
       dragging= start_drag= false;
     if (type == "release-right")
       right_dragging= start_right_drag= false;
-    if (mouse_graphics (type2, x, y, t)) return;
+    if (mouse_graphics (type2, x, y, mods, t)) return;
     if (!over_graphics (x, y))
       eval ("(graphics-reset-context 'text-cursor)");
   }
 
   if (type == "press-left") mouse_click (x, y);
   if (dragging && (type == "move")) {
-    if (attached () && dis->check_event (DRAG_EVENT)) return;
+    if (is_attached (this) && check_event (DRAG_EVENT)) return;
     mouse_drag (x, y);
   }
   if (type == "release-left" || type == "release-right") {
     dragging= right_dragging= false;
-    this << emit_mouse_grab (false);
+    send_mouse_grab (this, false);
     if ((t >= last_click) && ((t - last_click) <= 250)) {
       last_click= t;
       if (mouse_extra_click (x, y))
@@ -94,7 +95,7 @@ edit_interface_rep::mouse_any (string type, SI x, SI y, time_t t) {
     }
     else {
       last_click= t;
-      mouse_select (x, y);
+      mouse_select (x, y, mods);
     }
   }
   if (type == "press-middle") mouse_paste (x, y);
@@ -120,7 +121,7 @@ edit_interface_rep::mouse_click (SI x, SI y) {
   start_y   = y;
   start_drag= dragging= true;
   start_right_drag= right_dragging= false;
-  this << emit_mouse_grab (true);
+  send_mouse_grab (this, true);
 }
 
 bool
@@ -157,9 +158,9 @@ edit_interface_rep::mouse_drag (SI x, SI y) {
 }
 
 void
-edit_interface_rep::mouse_select (SI x, SI y) {
+edit_interface_rep::mouse_select (SI x, SI y, int mods) {
   if (eb->action ("select" , x, y, 0) != "") return;
-  if (!nil (active_ids) && (get_kbd_modifiers () & 1) == 0) {
+  if (!is_nil (active_ids) && (mods & 256) == 0) {
     call ("link-follow-ids", object (active_ids));
     return;
   }
@@ -195,18 +196,23 @@ edit_interface_rep::mouse_adjust (SI x, SI y) {
   if (eb->action ("adjust", x, y, 0) != "") return;
   x /= sfactor; y /= sfactor;
   abs_round (x, y);
-  if (popup_win == NULL) {
+  if (is_nil (popup_win)) {
     SI wx, wy;
-    win->get_position (wx, wy);
+    ::get_position (get_window (this), wx, wy);
     widget wid;
     SERVER (menu_widget ("(vertical (link texmacs-popup-menu))", wid));
-    widget popup_wid= popup_widget (wid, center);
-    popup_win= popup_window (popup_wid, wx+ ox+ x, wy+ oy+ y);
-    popup_win->map ();
-    this << emit_mouse_grab (true);
-    popup_wid << set_integer ("grabbed", 1);
-    // popup_wid << set_integer ("freeze", 1);
-    popup_wid << emit_mouse_grab (true);
+    widget popup_wid= popup_widget (wid);
+    popup_win= ::popup_window_widget (popup_wid, "Popup menu");
+#ifdef AQUATEXMACS
+    SI ox, oy;
+    get_position (this, ox, oy);
+    set_position (popup_win, wx+     x, wy+     y);
+#else
+    set_position (popup_win, wx+ ox+ x, wy+ oy+ y);
+#endif
+    set_visibility (popup_win, true);
+    send_keyboard_focus (this);
+    send_mouse_grab (popup_wid, true);
   }
 }
 
@@ -217,7 +223,7 @@ edit_interface_rep::mouse_scroll (SI x, SI y, bool up) {
   SI dy= 100*PIXEL;
   if (!up) dy= -dy;
   path sp= find_innermost_scroll (eb, tp);
-  if (nil (sp)) {
+  if (is_nil (sp)) {
     SERVER (scroll_where (x, y));
     y += dy;
     SERVER (scroll_to (x, y));
@@ -254,7 +260,7 @@ cursor
 edit_interface_rep::get_cursor () {
   if (inside_graphics ()) {
     frame f= find_frame ();
-    if (!nil (f)) {
+    if (!is_nil (f)) {
       point p= f [point (last_x, last_y)];
       p= f (adjust (p));
       SI x= (SI) p[0];
@@ -267,14 +273,14 @@ edit_interface_rep::get_cursor () {
 
 void
 edit_interface_rep::set_pointer (string name) {
-  sv->get_display()->set_pointer(name);
+  send_mouse_pointer (this, name);
 }
 
 void
 edit_interface_rep::set_pointer (
   string curs_name, string mask_name)
 {
-  sv->get_display()->set_pointer(curs_name, mask_name);
+  send_mouse_pointer (this, curs_name, mask_name);
 }
 
 /******************************************************************************
@@ -298,9 +304,9 @@ edit_interface_rep::update_active_loci () {
 
   locus_new_rects= rectangles ();
   active_ids= list<string> ();
-  if (!nil (ids1 * ids2) && !has_changed (THE_FOCUS)) {
+  if (!is_nil (ids1 * ids2) && !has_changed (THE_FOCUS)) {
     list<tree> l= as_list_tree (call ("link-active-upwards", object (mt)));
-    while (!nil (l)) {
+    while (!is_nil (l)) {
       tree lt= l->item;
       path lp= reverse (obtain_ip (lt));
       selection sel= eb->find_check_selection (lp * start(lt), lp * end(lt));
@@ -309,7 +315,7 @@ edit_interface_rep::update_active_loci () {
     }
     ids1= as_list_string (call ("link-active-ids", object (ids1)));
     ids2= as_list_string (call ("link-active-ids", object (ids2)));
-    if (nil (ids1)) rs1= rectangles ();
+    if (is_nil (ids1)) rs1= rectangles ();
     // FIXME: we should keep track which id corresponds to which rectangle
     locus_new_rects= rs1 * rs2;
     active_ids= ids1 * ids2;
@@ -322,10 +328,9 @@ edit_interface_rep::update_active_loci () {
 ******************************************************************************/
 
 void
-edit_interface_rep::handle_mouse (mouse_event ev) {
-  string type= ev->type;
-  SI     x   = ev->x*sfactor;
-  SI     y   = ev->y*sfactor;
-  //cout << type << " (" << x << ", " << y << ") at " << ev->t << "\n";
-  mouse_any (type, x, y, ev->t);
+edit_interface_rep::handle_mouse (string kind, SI x, SI y, int m, time_t t) {
+  x *= sfactor;
+  y *= sfactor;
+  //cout << kind << " (" << x << ", " << y << "; " << m << ") at " << t << "\n";
+  mouse_any (kind, x, y, m, t);
 }
