@@ -11,7 +11,7 @@
 ******************************************************************************/
 
 #include "edit_modify.hpp"
-#include "tm_buffer.hpp"
+#include "tm_window.hpp"
 #ifdef EXPERIMENTAL
 #include "../../Style/Memorizer/clean_copy.hpp"
 #endif
@@ -314,7 +314,7 @@ edit_modify_rep::post_notify (path p) {
 static tree
 encode (string op, path p, tree t) {
   string s= copy (op);
-  while (!nil (p)) {
+  while (!is_nil (p)) {
     s << ";" << as_string (p->item);
     p= p->next;
   }
