@@ -13,7 +13,11 @@
 #ifndef EDITOR_H
 #define EDITOR_H
 #include "typesetter.hpp"
-#include "Widget/attribute_widget.hpp"
+#ifdef AQUATEXMACS
+#include "Cocoa/aqua_simple_widget.h"
+#else
+#include "Widkit/simple_wk_widget.hpp"
+#endif
 #include "server.hpp"
 #include "scheme.hpp"
 #include "drd_info.hpp"
@@ -36,7 +40,7 @@ class tm_buffer_rep;
 typedef tm_buffer_rep* tm_buffer;
 class server_rep;
 
-class editor_rep: public attribute_widget_rep {
+class editor_rep: public simple_widget_rep {
 public:
   server_rep* sv;   // the underlying texmacs server
 
@@ -107,7 +111,7 @@ protected:
 
 public:
   editor_rep ();
-  editor_rep (server_rep* sv, display dis, tm_buffer buf);
+  editor_rep (server_rep* sv, tm_buffer buf);
   inline virtual ~editor_rep () {}
 
   /* public routines from edit_interface */
@@ -136,12 +140,11 @@ public:
   virtual bool complete_try () = 0;
   virtual void complete_start (string prefix, array<string> compls) = 0;
   virtual bool complete_keypress (string key) = 0;
-  virtual unsigned int get_kbd_modifiers () = 0;
-  virtual void mouse_any (string s, SI x, SI y, time_t t) = 0;
+  virtual void mouse_any (string s, SI x, SI y, int mods, time_t t) = 0;
   virtual void mouse_click (SI x, SI y) = 0;
   virtual bool mouse_extra_click (SI x, SI y) = 0;
   virtual void mouse_drag (SI x, SI y) = 0;
-  virtual void mouse_select (SI x, SI y) = 0;
+  virtual void mouse_select (SI x, SI y, int mods) = 0;
   virtual void mouse_paste (SI x, SI y) = 0;
   virtual void mouse_adjust (SI x, SI y) = 0;
   virtual void mouse_scroll (SI x, SI y, bool up) = 0;
@@ -201,8 +204,8 @@ public:
   virtual tree   get_graphical_object () = 0;
   virtual void   set_graphical_object (tree t) = 0;
   virtual void   invalidate_graphical_object () = 0;
-  virtual void   draw_graphical_object (ps_device dev) = 0;
-  virtual bool   mouse_graphics (string s, SI x, SI y, time_t t) = 0;
+  virtual void   draw_graphical_object (renderer ren) = 0;
+  virtual bool   mouse_graphics (string s, SI x, SI y, int mods, time_t t) = 0;
 
   /* public routines from edit_typeset */
   virtual void     clear_local_info () = 0;
@@ -522,7 +525,7 @@ public:
 };
 
 class editor {
-  EXTEND_NULL(widget,editor);
+EXTEND_NULL(widget,editor);
 public:
   inline bool operator == (editor w) { return rep == w.rep; }
   inline bool operator != (editor w) { return rep != w.rep; }
