@@ -40,6 +40,13 @@
   (math-group-members math_group_members (array_string string))
   (math-symbol-type math_symbol_type (string string))
   (object->command as_command (command object))
+  (exec-delayed exec_delayed (void object))
+  (set-input-language set_input_language (void string))
+  (get-input-language get_input_language (string))
+  (set-output-language gui_set_output_language (void string))
+  (get-output-language get_output_language (string))
+  (translate translate (string string string string))
+  (color named_color (int string))
 
   ;; routines for trees
   (tree->stree tree_to_scheme_tree (scheme_tree tree))
@@ -122,6 +129,8 @@
   (locase-all locase_all (string string))
   (string-union string_union (string string string))
   (string-minus string_minus (string string string))
+  (string-encode tm_encode (string string))
+  (string-decode tm_decode (string string))
   (escape-generic escape_generic (string string))
   (escape-verbatim escape_verbatim (string string))
   (escape-shell escape_sh (string string))
@@ -141,9 +150,9 @@
   (serialize-texmacs tree_to_texmacs (string tree))
   (parse-texmacs-snippet texmacs_to_tree (tree string))
   (serialize-texmacs-snippet tree_to_texmacs (string tree))
-  (texmacs->scheme tree_to_scheme (string tree))
-  (scheme->texmacs scheme_document_to_tree (tree string))
-  (scheme-snippet->texmacs scheme_to_tree (tree string))
+  (texmacs->stm tree_to_scheme (string tree))
+  (stm->texmacs scheme_document_to_tree (tree string))
+  (stm-snippet->texmacs scheme_to_tree (tree string))
   (cpp-texmacs->verbatim tree_to_verbatim (string tree bool string))
   (cpp-verbatim-snippet->texmacs verbatim_to_tree (tree string bool string))
   (cpp-verbatim->texmacs verbatim_document_to_tree (tree string bool string))
@@ -275,37 +284,17 @@
   (connection-read connection_read (tree string string string))
 
   ;; widgets
-  (widget-hlist horizontal_list (widget array_widget))
-  (widget-named-hlist horizontal_list (widget array_widget array_string))
-  (widget-vlist vertical_list (widget array_widget))
-  (widget-named-vlist vertical_list (widget array_widget array_string))
+  (widget-hmenu horizontal_menu (widget array_widget))
   (widget-vmenu vertical_menu (widget array_widget))
-  (widget-tile tile (widget array_widget int))
-  (widget-named-tile tile (widget array_widget int array_string))
-  (widget-harray horizontal_array (widget array_widget int))
-  (widget-named-harray horizontal_array (widget array_widget array_string int))
-  (widget-switch switch_widget (widget array_widget array_string))
-  (widget-switch-init switch_widget (widget array_widget array_string int))
-  (widget-optional optional_widget (widget widget))
-  (widget-optional-init optional_widget (widget widget bool))
-  (widget-glue glue_widget (widget bool bool int int))
-  (widget-separator separator_widget (widget int int bool))
-  (widget-text text_widget (widget string bool string))
-  (widget-xpm xpm_widget (widget url bool))
-  (widget-menu-text menu_text_widget (widget string int string bool))
-  (widget-command-button-1 command_button (widget widget command bool))
-  (widget-command-button-2 command_button (widget widget widget command))
-  (widget-command-button-3 command_button
-			   (widget widget widget widget command bool bool))
-  (widget-pulldown-button pulldown_button (widget widget widget))
-  (widget-pullright-button pullright_button (widget widget widget))
-  ;;(widget-popup popup_widget (widget widget gravity))
-  ;;(widget-canvas canvas_widget (widget widget gravity))
-  ;;(widget-text-input input_text_widget (widget command))
-  ;;(widget-file-chooser file_chooser_widget (widget command string string))
+  (widget-tmenu tile_menu (widget array_widget int))
+  (widget-separator menu_separator (widget bool))
+  (widget-menu-group menu_group (widget string string))
+  (widget-pulldown-button pulldown_button (widget widget promise_widget))
+  (widget-pullright-button pullright_button (widget widget promise_widget))
+  (widget-menu-button menu_button (widget widget command string string bool))
   (widget-balloon balloon_widget (widget widget widget))
-  (widget-pulldown-button-lazy pulldown_button (widget widget make_widget))
-  (widget-pullright-button-lazy pullright_button (widget widget make_widget))
-  (widget-wait wait_widget (widget int int string))
+  (widget-empty empty_widget (widget))
+  (widget-text text_widget (widget string int bool string))
+  (widget-xpm xpm_widget (widget url))
   (widget-box box_widget (widget scheme_tree string int bool bool))
-  (object->make-widget as_make_widget (make_widget object)))
+  (object->promise-widget as_promise_widget (promise_widget object)))
