@@ -44,7 +44,7 @@
   (insert insert_tree (void content))
   (insert-go-to var_insert_tree (void content path))
   (insert-raw-go-to insert_tree (void content path))
-  (insert-return insert_return (void))
+  (insert-raw-return insert_return (void))
   (remove-text remove_text (void bool))
   (remove-structure remove_structure (void bool))
   (remove-structure-upwards remove_structure_upwards (void))
@@ -153,7 +153,6 @@
   (emulate-keyboard emulate_keyboard (void string))
   (emulate-keyboard-message emulate_keyboard (void string string))
   (complete-try? complete_try (bool))
-  (get-keyboard-modifiers get_kbd_modifiers (int))
   
   ;; moving the cursor
   (go-to-path go_to (void path))
