@@ -18,11 +18,11 @@
 #include "convert.hpp"
 #include "file.hpp"
 #include "sys_utils.hpp"
-#include "Tmfs/tmfs.hpp"
+#include "tmfs.hpp"
 #include "client_server.hpp"
 #include "analyze.hpp"
 #include "tree_traverse.hpp"
-#include "tm_layout.hpp"
+#include "tm_frame.hpp"
 #include "Concat/concater.hpp"
 #include "converter.hpp"
 #include "timer.hpp"
@@ -31,6 +31,7 @@
 #include "Freetype/tt_file.hpp"
 #include "Bibtex/bibtex.hpp"
 #include "link.hpp"
+#include "dictionary.hpp"
 #include <string.h>
 #include <libguile.h>
 
@@ -341,7 +342,7 @@ tree_append (tree t1, tree t2) {
 bool
 tree_active (tree t) {
   path ip= obtain_ip (t);
-  return nil (ip) || last_item (ip) != DETACHED;
+  return is_nil (ip) || last_item (ip) != DETACHED;
 }
 
 tree
@@ -362,7 +363,7 @@ tree_child_insert (tree t, int pos, tree x) {
 
 static inline bool
 ip_attached (path ip) {
-  return nil (ip) || last_item (ip) != DETACHED;
+  return is_nil (ip) || last_item (ip) != DETACHED;
 }
 
 tree
@@ -569,7 +570,7 @@ scm_is_path (SCM p) {
 
 SCM
 path_to_scm (path p) {
-  if (nil (p)) return SCM_NULL;
+  if (is_nil (p)) return SCM_NULL;
   else return scm_cons (int_to_scm (p->item), path_to_scm (p->next));
 }
 
@@ -634,55 +635,6 @@ observerP (SCM t) {
   return bool_to_scm (b);
 }
 
-/******************************************************************************
-* Displays
-******************************************************************************/
-
-static long display_tag;
-
-#define scm_is_display(dis) \
-  (SCM_NIMP (dis) && (((long) SCM_CAR (dis)) == display_tag))
-#define SCM_ASSERT_DISPLAY(dis,arg,rout) \
-  SCM_ASSERT (scm_is_display (dis), dis, arg, rout)
-
-/*static*/ SCM
-display_to_scm (display dis) {
-  SCM display_smob;
-  SET_SMOB (display_smob, (void*) (new display (dis)), (SCM) display_tag);
-  return display_smob;
-}
-
-static display
-scm_to_display (SCM display_smob) {
-  return *((display*) SCM_CDR (display_smob));
-}
-
-static SCM
-mark_display (SCM display_smob) {
-  (void) display_smob;
-  return SCM_BOOL_F;
-}
-
-static scm_sizet
-free_display (SCM display_smob) {
-  display *ptr = (display *) SCM_CDR (display_smob);
-  delete ptr;
-  return 0;
-}
-
-static int
-print_display (SCM display_smob, SCM port, scm_print_state *pstate) {
-  (void) display_smob; (void) pstate;
-  string s= "<display>";
-  scm_display (string_to_scm (s), port);
-  return 1;
-}
-
-static SCM
-cmp_display (SCM dis1, SCM dis2) {
-  return scm_bool2scm (scm_to_display (dis1) == scm_to_display (dis2));
-}
-
 /******************************************************************************
 * Widgets
 ******************************************************************************/
@@ -741,53 +693,58 @@ cmp_widget (SCM wid1, SCM wid2) {
 * Widget factory
 ******************************************************************************/
 
-static long make_widget_tag;
+typedef promise<widget> promise_widget;
 
-#define SCM_ASSERT_MAKE_WIDGET(mw,arg,rout) \
-  SCM_ASSERT (scm_is_make_widget (mw), mw, arg, rout)
+static long promise_widget_tag;
 
-#define scm_is_make_widget(mw) \
-  (SCM_NIMP (mw) && (((long) SCM_CAR (mw)) == make_widget_tag))
+#define SCM_ASSERT_PROMISE_WIDGET(pw,arg,rout) \
+  SCM_ASSERT (scm_is_promise_widget (pw), pw, arg, rout)
+
+#define scm_is_promise_widget(pw) \
+  (SCM_NIMP (pw) && (((long) SCM_CAR (pw)) == promise_widget_tag))
 
 static SCM
-make_widget_to_scm (make_widget mw) {
-  SCM make_widget_smob;
-  SET_SMOB (make_widget_smob,
-	    (void*) (new make_widget (mw)),
-	    (SCM) make_widget_tag);
-  return make_widget_smob;
+promise_widget_to_scm (promise_widget pw) {
+  SCM promise_widget_smob;
+  SET_SMOB (promise_widget_smob,
+	    (void*) (new promise_widget (pw)),
+	    (SCM) promise_widget_tag);
+  return promise_widget_smob;
 }
 
-static make_widget
-scm_to_make_widget (SCM make_widget_smob) {
-  return *((make_widget*) SCM_CDR (make_widget_smob));
+static promise_widget
+scm_to_promise_widget (SCM promise_widget_smob) {
+  return *((promise_widget*) SCM_CDR (promise_widget_smob));
 }
 
 static SCM
-mark_make_widget (SCM make_widget_smob) {
-  (void) make_widget_smob;
+mark_promise_widget (SCM promise_widget_smob) {
+  (void) promise_widget_smob;
   return SCM_BOOL_F;
 }
 
 static scm_sizet
-free_make_widget (SCM make_widget_smob) {
-  make_widget *ptr = (make_widget *) SCM_CDR (make_widget_smob);
+free_promise_widget (SCM promise_widget_smob) {
+  promise_widget *ptr = (promise_widget *) SCM_CDR (promise_widget_smob);
   delete ptr;
   // should be replaced by total size of the widget factory
   return 0;
 }
 
 static int
-print_make_widget (SCM make_widget_smob, SCM port, scm_print_state *pstate) {
-  (void) make_widget_smob; (void) pstate;
-  string s= "<make-widget>";
+print_promise_widget (SCM promise_widget_smob, SCM port,
+		      scm_print_state *pstate)
+{
+  (void) promise_widget_smob; (void) pstate;
+  string s= "<promise-widget>";
   scm_display (string_to_scm (s), port);
   return 1;
 }
 
 static SCM
-cmp_make_widget (SCM mw1, SCM mw2) {
-  return scm_bool2scm (scm_to_make_widget (mw1) == scm_to_make_widget (mw2));
+cmp_promise_widget (SCM pw1, SCM pw2) {
+  return scm_bool2scm (scm_to_promise_widget (pw1) ==
+		       scm_to_promise_widget (pw2));
 }
 
 /******************************************************************************
@@ -1167,7 +1124,7 @@ scm_is_list_string (SCM p) {
 
 SCM
 list_string_to_scm (list_string l) {
-  if (nil (l)) return SCM_NULL;
+  if (is_nil (l)) return SCM_NULL;
   return scm_cons (string_to_scm (l->item),
 		   list_string_to_scm (l->next));
 }
@@ -1194,7 +1151,7 @@ scm_is_list_tree (SCM p) {
 
 SCM
 list_tree_to_scm (list_tree l) {
-  if (nil (l)) return SCM_NULL;
+  if (is_nil (l)) return SCM_NULL;
   return scm_cons (tree_to_scm (l->item),
 		   list_tree_to_scm (l->next));
 }
@@ -1231,37 +1188,33 @@ scm_to_collection (SCM p) {
 
 void
 initialize_glue () {
-  tree_tag= scm_make_smob_type ("tree", 0);
+  tree_tag= scm_make_smob_type (const_cast<char*> ("tree"), 0);
   scm_set_smob_mark (tree_tag, mark_tree);
   scm_set_smob_free (tree_tag, free_tree);
   scm_set_smob_print (tree_tag, print_tree);
   scm_set_smob_equalp (tree_tag, cmp_tree);
-  observer_tag= scm_make_smob_type ("observer", 0);
+  observer_tag= scm_make_smob_type (const_cast<char*> ("observer"), 0);
   scm_set_smob_mark (observer_tag, mark_observer);
   scm_set_smob_free (observer_tag, free_observer);
   scm_set_smob_print (observer_tag, print_observer);
   scm_set_smob_equalp (observer_tag, cmp_observer);
-  display_tag= scm_make_smob_type ("display", 0);
-  scm_set_smob_mark (display_tag, mark_display);
-  scm_set_smob_free (display_tag, free_display);
-  scm_set_smob_print (display_tag, print_display);
-  scm_set_smob_equalp (display_tag, cmp_display);
-  widget_tag= scm_make_smob_type ("widget", 0);
+  widget_tag= scm_make_smob_type (const_cast<char*> ("widget"), 0);
   scm_set_smob_mark (widget_tag, mark_widget);
   scm_set_smob_free (widget_tag, free_widget);
   scm_set_smob_print (widget_tag, print_widget);
   scm_set_smob_equalp (widget_tag, cmp_widget);
-  make_widget_tag= scm_make_smob_type ("make-widget", 0);
-  scm_set_smob_mark (make_widget_tag, mark_make_widget);
-  scm_set_smob_free (make_widget_tag, free_make_widget);
-  scm_set_smob_print (make_widget_tag, print_make_widget);
-  scm_set_smob_equalp (make_widget_tag, cmp_make_widget);
-  command_tag= scm_make_smob_type ("command", 0);
+  promise_widget_tag=
+    scm_make_smob_type (const_cast<char*> ("promise-widget"), 0);
+  scm_set_smob_mark (promise_widget_tag, mark_promise_widget);
+  scm_set_smob_free (promise_widget_tag, free_promise_widget);
+  scm_set_smob_print (promise_widget_tag, print_promise_widget);
+  scm_set_smob_equalp (promise_widget_tag, cmp_promise_widget);
+  command_tag= scm_make_smob_type (const_cast<char*> ("command"), 0);
   scm_set_smob_mark (command_tag, mark_command);
   scm_set_smob_free (command_tag, free_command);
   scm_set_smob_print (command_tag, print_command);
   scm_set_smob_equalp (command_tag, cmp_command);
-  url_tag= scm_make_smob_type ("url", 0);
+  url_tag= scm_make_smob_type (const_cast<char*> ("url"), 0);
   scm_set_smob_mark (url_tag, mark_url);
   scm_set_smob_free (url_tag, free_url);
   scm_set_smob_print (url_tag, print_url);
@@ -1285,16 +1238,13 @@ scm_smobfuns observer_smob_funcs = {
   mark_observer, free_observer, print_observer, cmp_observer
 };
 
-scm_smobfuns display_smob_funcs = {
-  mark_display, free_display, print_display, cmp_display
-};
-
 scm_smobfuns widget_smob_funcs = {
   mark_widget, free_widget, print_widget, cmp_widget
 };
 
-scm_smobfuns make_widget_smob_funcs = {
-  mark_make_widget, free_make_widget, print_make_widget, cmp_make_widget
+scm_smobfuns promise_widget_smob_funcs = {
+  mark_promise_widget, free_promise_widget,
+  print_promise_widget, cmp_promise_widget
 };
 
 scm_smobfuns command_smob_funcs = {
@@ -1309,9 +1259,8 @@ void
 initialize_glue () {
   tree_tag= scm_newsmob (&tree_smob_funcs);
   observer_tag= scm_newsmob (&observer_smob_funcs);
-  display_tag= scm_newsmob (&display_smob_funcs);
   widget_tag= scm_newsmob (&widget_smob_funcs);
-  make_widget_tag= scm_newsmob (&make_widget_smob_funcs);
+  promise_widget_tag= scm_newsmob (&promise_widget_smob_funcs);
   command_tag= scm_newsmob (&command_smob_funcs);
   url_tag= scm_newsmob (&url_smob_funcs);
   scm_new_procedure ("tree?", (FN) treeP, 1, 0, 0);
