@@ -15,6 +15,8 @@
 #include "file.hpp"
 #include "web_files.hpp"
 #include "socket_server.hpp"
+#include "message.hpp"
+#include "dictionary.hpp"
 #ifdef EXPERIMENTAL
 #include "../../Style/Memorizer/clean_copy.hpp"
 #endif
@@ -56,8 +58,7 @@ string
 tm_data_rep::new_menu_name (url u) {
   string name= as_string (tail (u));
   if (starts (name, "no_name_") && ends (name, ".tm")) {
-    display dis= current_display ();
-    string lan= dis->get_output_language ();
+    string lan= get_output_language ();
     string no_name= translate ("No name", "english", lan);
     for (int i=0; i<N(no_name); i++)
       if (((unsigned char) (no_name[i])) >= (unsigned char) 128)
@@ -249,7 +250,7 @@ tm_data_rep::set_abbr_buffer (string abbr) {
   for (i=0; i<N(buf->vws); i++) {
     tm_view vw2= buf->vws[i];
     if (vw2->win != NULL)
-      vw2->win->win->set_name (buf->abbr);
+      vw2->win->set_window_name (buf->abbr);
   }
 }
 
@@ -331,20 +332,21 @@ tm_data_rep::delete_view (tm_view vw) {
 	else a[j]= buf->vws[j+1];
       buf->vws= a;
     }
-  delete vw;
+  // delete vw;
+  // FIXME: causes very annoying segfault;
+  // recently introduced during reorganization
 }
 
 void
 tm_data_rep::attach_view (tm_window win, tm_view vw) {
   // cout << "Attach view " << vw->buf->name << "\n";
   vw->win= win;
-  widget wid= (widget) win->wid;
-  wid ["canvas"] << set_widget ("scrollable", vw->ed);
-  if (wid->attached ()) {
-    vw->ed->resume ();
-    win->wid->set_window_name (vw->buf->abbr);
-    wid ["canvas"] << emit_update ();
-  }
+  widget wid= win->wid;
+  set_canvas (wid, vw->ed);
+  if (!is_attached (wid))
+    fatal_error ("widget should be attached", "tm_data_rep::attach_view");
+  vw->ed->resume ();
+  win->set_window_name (vw->buf->abbr);
   // cout << "View attached\n";
 }
 
@@ -354,14 +356,12 @@ tm_data_rep::detach_view (tm_view vw) {
   tm_window win= vw->win;
   if (win == NULL) return;
   vw->win= NULL;
-  widget wid= (widget) win->wid;
-  wid ["canvas"] << set_widget ("scrollable", glue_widget ());
-  if (wid->attached ()) {
-    vw->ed->suspend ();
-    vw->ed << emit_attach_window (NULL);
-    win->wid->set_window_name ("TeXmacs");
-    wid ["canvas"] << emit_update ();
-  }
+  widget wid= win->wid;
+  if (!is_attached (wid))
+    fatal_error ("widget should be attached", "tm_data_rep::attach_view");
+  vw->ed->suspend ();
+  set_canvas (wid, glue_widget ());
+  win->set_window_name ("TeXmacs");
   // cout << "View detached\n";
 }
 
@@ -369,10 +369,24 @@ tm_data_rep::detach_view (tm_view vw) {
 * Low level window routines
 ******************************************************************************/
 
+class kill_window_command_rep: public command_rep {
+public:
+  inline kill_window_command_rep () {}
+  inline void apply () { exec_delayed (scheme_cmd ("(safely-kill-window)")); }
+  ostream& print (ostream& out) { return out << "kill window"; }
+};
+
 tm_window
-tm_data_rep::new_window (display dis, bool map_flag, tree geom) {
-  tm_window win= new tm_window_rep (new tm_widget_rep (this, dis), geom);
-  if (map_flag) win->win->map ();
+tm_data_rep::new_window (bool map_flag, tree geom) {
+  int mask= 0;
+  if (get_preference ("header") == "on") mask += 1;
+  if (get_preference ("main icon bar") == "on") mask += 2;
+  if (get_preference ("context dependent icons") == "on") mask += 4;
+  if (get_preference ("user provided icons") == "on") mask += 8;
+  if (get_preference ("status bar") == "on") mask += 16;
+  command quit= new kill_window_command_rep ();
+  tm_window win= new tm_window_rep (texmacs_widget (mask, quit), geom);
+  if (map_flag) win->map ();
   return win;
 }
 
@@ -396,8 +410,8 @@ tm_data_rep::delete_view_from_window (tm_window win) {
 void
 tm_data_rep::delete_window (tm_window win) {
   while (delete_view_from_window (win));
-  win->win->unmap ();
-  delete win->win;
+  win->unmap ();
+  destroy_window_widget (win->win);
   delete win;
 }
 
@@ -417,7 +431,7 @@ tm_data_rep::new_buffer_in_this_window (url name, tree doc) {
 
 void
 tm_data_rep::new_buffer_in_new_window (url name, tree doc, tree geom) {
-  tm_window win= new_window (get_display (), true, geom);
+  tm_window win= new_window (true, geom);
   tm_buffer buf= new_buffer (name, doc);
   tm_view   vw = get_passive_view (buf);
   attach_view (win, vw);
@@ -471,8 +485,8 @@ tm_data_rep::switch_to_buffer (int nr) {
   attach_view (win, new_vw);
   set_view (new_vw);
   menu_focus_buffer (buf);
-  tm_widget meta= new_vw->win->wid;
-  meta->set_shrinking_factor (meta->get_shrinking_factor ());
+  tm_window nwin= new_vw->win;
+  nwin->set_shrinking_factor (nwin->get_shrinking_factor ());
   // cout << "Switched to buffer " << nr << "\n";
 }
 
@@ -568,7 +582,7 @@ tm_data_rep::open_window (tree geom) {
 
 void
 tm_data_rep::clone_window () {
-  tm_window win= new_window (get_display ());
+  tm_window win= new_window ();
   tm_buffer buf= get_buffer ();
   tm_view   vw = get_passive_view (buf);
   attach_view (win, vw);
@@ -763,7 +777,7 @@ path
 new_document () {
   int i, n= N(the_et);
   for (i=0; i<n; i++)
-    if (the_et[i] == UNINIT && nil (the_et[i]->obs)) {
+    if (the_et[i] == UNINIT && is_nil (the_et[i]->obs)) {
       assign (the_et[i], tree (DOCUMENT, ""));
       return path (i); // obtain_ip (the_et[i]);
     }
@@ -806,7 +820,7 @@ create_window_id () {
 
 static path
 remove (path p, int i) {
-  if (nil (p)) return p;
+  if (is_nil (p)) return p;
   else if (p->item == i) return p->next;
   else return path (p->item, remove (p->next, i));
 }
